@@ -2,7 +2,7 @@ package Nephia;
 use strict;
 use warnings;
 use File::Spec;
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 sub import {
     my ($class, %opts) = @_;
@@ -91,7 +91,7 @@ This controller outputs response-value as JSON, and will be mounted on "/foobar"
 Attention to "template" attribute. 
 If you specified it, controller searches template file from view-directory and render it.
 
-If you use multibyte-string in response, please remember 'use utf8;' and, you may specify character-set as like as following.
+If you use multibyte-string in response, please remember C<use utf8> and, you may specify character-set as like as following.
 
   use utf8; ### <- very important
   path '/' => sub {
@@ -102,7 +102,7 @@ If you use multibyte-string in response, please remember 'use utf8;' and, you ma
       };
   };
 
-If you not specified 'charset', it will be 'UTF-8'.
+If you not specified C<charset>, it will be 'UTF-8'.
 
 =head2 Makes response - Using "res" function
 
@@ -113,9 +113,9 @@ If you not specified 'charset', it will be 'UTF-8'.
       };
   };
 
-"res" function returns Plack::Response object with customisable DSL-like syntax.
+"res" function returns Plack::Response object with some DSL.
 
-You may specify coderef that's passed to res() returns some value. These values are passed into arrayref that is as plack response.
+You may specify code-reference that's passed to res() returns some value. These values are passed into arrayref that is as plack response.
 
   path '/some/path' => sub {
       res { ( 200, ['text/html; charset=utf8'], ['Wooootheee!!!'] ) };
@@ -173,9 +173,36 @@ Please see Plack::Response's documentation for more detail.
       ...
   };
 
+=head2 Submapping to other applications that use Nephia
+
+It's easy. Call "path" function by package instead of a coderef.
+
+  path '/otherapp' => 'OtherApp';
+
+in OtherApp:
+
+  package OtherApp;
+  use Nephia;
+
+  get '/message' => sub {
+      message => 'this is other app!'
+  };
+
+This controller mapped to "/otherapp/message".
+
+Can use "+" prefix in package name. This prefix replace to package of myself.
+
+Example:
+
+  package MyApp;
+
+  path '/childapp' => '+Child';
+
+"/chilapp" connect to "MyApp::Child".
+
 =head1 USING CONFIG
 
-First, see app.psgi that generated by nephia-setup.
+First, see app.psgi that generated by C<nephia-setup>.
 
   use strict;
   use warnings;
@@ -199,7 +226,7 @@ And, you can access to these config in your application as following.
     my $config = config;
   };
 
-=head1 STATIC CONTENTS ( like as images, javascripts... )
+=head1 STATIC CONTENTS ( like as image, javascript ... )
 
 You can look static-files that is into root directory via HTTP.
 
@@ -270,11 +297,11 @@ Usage equal as path(). But these functions specifies limitation for HTTP request
 
 =head2 req
 
-Return Plack::Request object. You can call this function in coderef that is argument of path().
+Return Plack::Request object. You can call this function in code-reference that is argument of path().
 
 =head2 res $coderef
 
-Return Plack::Response object with customisable DSL-like syntax.
+Return Plack::Response object with some DSL.
 
 =head2 param
 
@@ -290,9 +317,13 @@ Load specified Nephia plugins.
 
 =head1 AUTHOR
 
-ytnobody E<lt>ytnobody@gmail.comE<gt>
+C<ytnobody> E<lt>ytnobody@gmail.comE<gt>
 
-ichigotake
+C<ichigotake>
+
+C<papix>
+
+and Nephia contributors, hachioji.pm
 
 =head1 SEE ALSO
 
